import mmh3
from bitarray import bitarray
import numpy as np


class BloomFilter:
    """
    capacity: bloom过滤器大小
    hash_size: hash函数个数
    """

    def __init__(self, capacity=1000, hash_size=10):
        self._capacity = capacity
        self._hash_size = hash_size
        self._bit_array = bitarray(self._capacity)
        self._bit_array.setall(0)

    def add(self, element):
        position_list = self._handle_position(str(element))
        for position in position_list:
            self._bit_array[position] = 1

    def query(self, element):
        position_list = self._handle_position(str(element))

        result = True
        for position in position_list:
            result = self._bit_array[position] and result
        return result

    def _handle_position(self, element):
        postion_list = []
        for i in range(self._hash_size):
            index = mmh3.hash(element, i) % self._capacity
            postion_list.append(index)
        return postion_list



import requests
import re
from bs4 import BeautifulSoup as Be
import os


def fbi_warning(page=2):
    """

    :param page: 下载图片页数，int型整数
    :return:
    """
    headers = {
        'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/86.0.4240.111 Safari/537.36',
    }

    if not os.path.exists("FBIWarning"):
        os.makedirs("FBIWarning")

    num = 1
    for i in range(page):
        url = f"https://m.bcoderss.com/tag/美女/page/{i + 1}/"

        r = requests.get(url=url, headers=headers)
        html = r.text

        b = Be(html, 'lxml')
        img_url = b.find_all('img', class_="attachment-thumbnail size-thumbnail wp-post-image")
        try:
            for img in img_url:
                # print(a)
                e = re.search('<img alt=.*? class=.*? height=.*? src="(.*?)" title.*? width=.*?/>', str(img), re.S)
                print(f"第{i + 1}页|第{num}张图片：", e.group(1))
                get_img = requests.get(url=e.group(1))
                with open(f'FBIWarning/{num}.jpg', 'ab') as f:
                    f.write(get_img.content)
                num += 1
                # time.sleep(1)如。
        except:
            continue



import setuptools

setuptools.setup(
    name="pybitds",
    version="0.0.5",
    author="byteschen",
    author_email="czj1132163229@163.com",
    description="pybitds",
    long_description="beginner",
    url="https://github.com/BytesChen/beginner",
    packages=setuptools.find_packages(),
    python_requires='>=3.6',
    install_requires=["numpy", "bitarray", "mmh3", "beautifulsoup4"]
)
